@@ -1,5 +1,4 @@
 from .base import Handler
-from ..loader import HANDLERS
 from .. import filters
 
 
@@ -25,7 +24,6 @@ def callback_query(
             func = func.func
 
         handler = Handler(func, _filters)
-        HANDLERS.append(handler)
         return handler
 
     return _
